@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 #
 # This file is part of Invenio.
-# Copyright (C) 2016-2018 CERN.
+# Copyright (C) 2016-2022 CERN.
 # Copyright (C) 2016 TIND.
 #
 # Invenio is free software; you can redistribute it and/or modify it
@@ -9,14 +9,12 @@
 
 """Flask exension for Invenio-Indexer."""
 
-from __future__ import absolute_import, print_function
-
-import six
 from flask import current_app
 from werkzeug.utils import cached_property, import_string
 
 from . import config
 from .cli import run  # noqa
+from .registry import IndexerRegistry
 from .signals import before_record_index
 
 
@@ -37,11 +35,12 @@ class InvenioIndexer(object):
         :param app: The Flask application.
         """
         self.init_config(app)
+        self.registry = IndexerRegistry()
         app.extensions['invenio-indexer'] = self
 
         hooks = app.config.get('INDEXER_BEFORE_INDEX_HOOKS', [])
         for hook in hooks:
-            if isinstance(hook, six.string_types):
+            if isinstance(hook, str):
                 hook = import_string(hook)
             before_record_index.connect_via(app)(hook)
 
